@@ -25,11 +25,9 @@ class CloudRunLogger(object):
             global_log_fields = {}
             # Add log correlation to nest all log messages
             # beneath request log in Log Viewer.
-            trace_header = self.request.headers.get('X-Cloud-Trace-Context')
-            if trace_header and self.project_id:
-                trace = trace_header.split('/')
-                global_log_fields['logging.googleapis.com/trace'] = (
-                    f"projects/{self.project_id}/traces/{trace[0]}")
+            trace_field = self._get_trace()
+            if trace_field:
+                global_log_fields['logging.googleapis.com/trace'] = trace_field
 
             # Complete a structured log entry.
             entry = dict(severity=severity,
@@ -40,6 +38,15 @@ class CloudRunLogger(object):
             print(json.dumps(entry))
             sys.stdout.flush()
 
+    def _get_trace(self):
+        if not self.request:
+            return None
+            
+        trace_header = self.request.headers.get('X-Cloud-Trace-Context')
+        if trace_header and self.project_id:
+            trace = trace_header.split('/')
+            return f"projects/{self.project_id}/traces/{trace[0]}"
+
     def info(self, message):
         self._do_log('INFO', message='MMS-INFO: {}'.format(message))
 
